// $Id: ARPPacket.java,v 1.4 2001/05/28 18:30:12 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;

import net.ultrametrics.console.AnsiEscapeSequences;


/**
 * An ARP protocol packet.
 * <p>
 * Extends an ethernet packet, adding ARP header information and an ARP 
 * data payload. 
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.4 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/28 18:30:12 $
 */
public class ARPPacket extends EthernetPacket
{
  /**
   * Create a new ARP packet.
   */
  public ARPPacket(int lLen, byte [] bytes, 
                   String hwSrcAddress, 
                   String hwDstAddress, 
                   String prSrcAddress, 
                   String prDstAddress,
                   int operation) {
    super(lLen, bytes, hwSrcAddress, hwDstAddress,
          // in the link-level header, classify this packet as ARP protocol
          EthernetProtocols.ETHERTYPE_ARP);

    int headerLen = ARPEncoding.HEADER_LEN;
    this.header = PacketEncoding.extractHeader(lLen, headerLen, bytes);
    this.data = PacketEncoding.extractData(lLen, headerLen, bytes);
    this.protoSenderAddress = prSrcAddress;
    this.protoTargetAddress = prDstAddress;
    this.operation = operation;
  }

  /**
   * Fetch the arp header, excluding arp data payload.
   */
  public byte [] getHeader() {
    return header;
  }

  /**
   * Fetch data portion of the arp header.
   */
  public byte [] getData() {
    return data;
  }

  /**
   * Convert this ARP packet to a readable string.
   */
  public String toString() {
    StringBuffer buffer = new StringBuffer();
    buffer.append('[');
    buffer.append(AnsiEscapeSequences.PURPLE);
    buffer.append("ARPPacket");
    buffer.append(AnsiEscapeSequences.RESET);
    buffer.append(": ");
    buffer.append(operation == OPERATION_REQUEST ? "request" : "reply");
    buffer.append(' ');
    buffer.append(macSourceAddress + " -> " + 
                  macDestinationAddress);
    buffer.append(", ");
    buffer.append(protoSenderAddress + " -> " + 
                  protoTargetAddress);
    buffer.append(" l=" + header.length + "," + data.length);
    buffer.append(']');

    return buffer.toString();
  }


  // todo: not all fields are currently getting populated

  /**
   * Operation.
   */
  int operation;

  /**
   * Hardware address type.
   */
  int hardwareAddressType;

  /**
   * Protocol address type.
   */
  int protocolAddressType;

  /**
   * Hardware address length.
   */
  int hardwareAddressLength;

  /**
   * Protocol address length.
   */
  int protocolAddressLength;

  /**
   * Sender hardware address.
   */
  // currently only storing in EthernetPacket, not reflecting the 
  // fact that the data is stored redundantly in actual ARP packets.
  //  String hwSenderAddress;

  /**
   * Target hardware address.
   */
  // currently only storing in EthernetPacket, not reflecting the 
  // fact that the data is stored redundantly in actual ARP packets.
  //String hwTargetAddress;

  /**
   * Sender protocol address.
   */
  String protoSenderAddress;

  /**
   * Target protocol address.
   */
  String protoTargetAddress;

  /**
   * Raw ARP data, including the ARP header and payload.
   */
  byte [] arpData;

  private static final int OPERATION_REQUEST = 0x1;
  private static final int OPERATION_REPLY = 0x2;

  private String _rcsid = 
    "$Id: ARPPacket.java,v 1.4 2001/05/28 18:30:12 pcharles Exp $";
}
