// $Id: EthernetProtocols.java,v 1.2 2001/05/24 03:23:26 pcharles Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;


/**
 * Code constants for well-defined ethernet protocols.
 * <p>
 * Taken from linux/if_ether.h and tcpdump/ethertype.h
 *
 * @author Patrick Charles and Jonas Lehmann
 * @version $Revision: 1.2 $
 * @lastModifiedBy $Author: pcharles $
 * @lastModifiedAt $Date: 2001/05/24 03:23:26 $
 */
public interface EthernetProtocols
{
  /**
   * IP protocol.
   */
  int ETHERTYPE_IP = 0x0800;

  /**
   * Address resolution protocol.
   */
  int ETHERTYPE_ARP = 0x0806;

  /**
   * Reverse address resolution protocol.
   */
  int ETHERTYPE_RARP = 0x8035;


  /**
   * Ethernet Loopback packet 
   */
  int ETHERTYPE_LOOP = 0x0060;

  /**
   * Ethernet Echo packet		
   */
  int ETHERTYPE_ECHO = 0x0200;

  /**
   * Xerox PUP packet
   */
  int ETHERTYPE_PUP = 0x0400;

  /**
   * CCITT X.25			
   */
  int ETHERTYPE_X25 = 0x0805;

  /**
   * G8BPQ AX.25 Ethernet Packet	[ NOT AN OFFICIALLY REGISTERED ID ] 
   */
  int ETHERTYPE_BPQ = 0x08FF;

  /**
   * DEC Assigned proto
   */
  int ETHERTYPE_DEC = 0x6000;

  /**
   * DEC DNA Dump/Load
   */
  int ETHERTYPE_DNA_DL = 0x6001;
  
  /**
   * DEC DNA Remote Console
   */
  int ETHERTYPE_DNA_RC = 0x6002;

  /**
   * DEC DNA Routing
   */
  int ETHERTYPE_DNA_RT = 0x6003;

  /**
   * DEC LAT
   */
  int ETHERTYPE_LAT = 0x6004;

  /**
   * DEC Diagnostics
   */
  int ETHERTYPE_DIAG = 0x6005;

  /**
   * DEC Customer use
   */
  int ETHERTYPE_CUST = 0x6006;

  /**
   * DEC Systems Comms Arch
   */
  int ETHERTYPE_SCA = 0x6007;

  /**
   * Appletalk DDP 
   */
  int ETHERTYPE_ATALK = 0x809B;

  /**
   * Appletalk AARP
   */
  int ETHERTYPE_AARP = 0x80F3;

  /**
   * IPX over DIX
   */
  int ETHERTYPE_IPX = 0x8137;

  /**
   * IPv6 over bluebook
   */
  int ETHERTYPE_IPV6 = 0x86DD;


  // Non DIX types. Won't clash for 1500 types.
 
  /**
   * Dummy type for 802.3 frames  
   */
  int ETHERTYPE_802_3 = 0x0001;

  /**
   * Dummy protocol id for AX.25  
   */
  int ETHERTYPE_AX25 = 0x0002;

  /**
   * Every packet (be careful!!!) 
   */
  int ETHERTYPE_ALL = 0x0003;

  /**
   * 802.2 frames
   */
  int ETHERTYPE_802_2 = 0x0004;

  /**
   * Internal only
   */
  int ETHERTYPE_SNAP = 0x0005;

  /**
   * DEC DDCMP: Internal only
   */
  int ETHERTYPE_DDCMP = 0x0006;

  /**
   * Dummy type for WAN PPP frames
   */
  int ETHERTYPE_WAN_PPP = 0x0007;

  /**
   * Dummy type for PPP MP frames 
   */
  int ETHERTYPE_PPP_MP = 0x0008;

  /**
   * Localtalk pseudo type 
   */
  int ETHERTYPE_LOCALTALK = 0x0009;

  /**
   * Dummy type for Atalk over PPP
   */
  int ETHERTYPE_PPPTALK = 0x0010;

  /**
   * 802.2 frames
   */
  int ETHERTYPE_TR_802_2 = 0x0011;

  /**
   * Mobitex (kaz@cafe.net)
   */
  int ETHERTYPE_MOBITEX = 0x0015;

  /**
   * Card specific control frames
   */
  int ETHERTYPE_CONTROL = 0x0016;

  /**
   * Linux/IR
   */
  int ETHERTYPE_IRDA = 0x0017;


  // others not yet documented..

  int ETHERTYPE_NS = 0x0600;

  int ETHERTYPE_SPRITE = 0x0500;

  int ETHERTYPE_TRAIL = 0x1000;

  int ETHERTYPE_LANBRIDGE = 0x8038;

  int ETHERTYPE_DECDNS = 0x803c;

  int ETHERTYPE_DECDTS = 0x803e;

  int ETHERTYPE_VEXP = 0x805b;

  int ETHERTYPE_VPROD = 0x805c;

  int ETHERTYPE_8021Q = 0x8100;

  int ETHERTYPE_PPP = 0x880b;

  int ETHERTYPE_PPPOED = 0x8863;

  int ETHERTYPE_PPPOES = 0x8864;

  int ETHERTYPE_LOOPBACK = 0x9000;

  int ETHERNET_UNKNOWN = 0x0;


  // these aren't valid ETHERNET codes, but show up in the type field.
  // spanning tree bridge protocol?
  int STBPDU = 0x0026;
}
